@@ -3,7 +3,7 @@
 from __future__ import absolute_import
 
 
-__all__ = ('main',)
+__all__ = ("main",)
 
 
 def main():
