@@ -7,8 +7,14 @@ from PyPDF2 import PdfFileReader, PdfFileWriter
 
 from .core import TableList
 from .parsers import Stream, Lattice
-from .utils import (TemporaryDirectory, get_page_layout, get_text_objects,
-                    get_rotation, is_url, download_url)
+from .utils import (
+    TemporaryDirectory,
+    get_page_layout,
+    get_text_objects,
+    get_rotation,
+    is_url,
+    download_url,
+)
 
 
 class PDFHandler(object):
@@ -27,19 +33,20 @@ class PDFHandler(object):
         Password for decryption.
 
     """
-    def __init__(self, filepath, pages='1', password=None):
+
+    def __init__(self, filepath, pages="1", password=None):
         if is_url(filepath):
             filepath = download_url(filepath)
         self.filepath = filepath
-        if not filepath.lower().endswith('.pdf'):
+        if not filepath.lower().endswith(".pdf"):
             raise NotImplementedError("File format not supported")
 
         if password is None:
-            self.password = ''
+            self.password = ""
         else:
             self.password = password
             if sys.version_info[0] < 3:
-                self.password = self.password.encode('ascii')
+                self.password = self.password.encode("ascii")
         self.pages = self._get_pages(self.filepath, pages)
 
     def _get_pages(self, filepath, pages):
@@ -60,26 +67,26 @@ class PDFHandler(object):
 
         """
         page_numbers = []
-        if pages == '1':
-            page_numbers.append({'start': 1, 'end': 1})
+        if pages == "1":
+            page_numbers.append({"start": 1, "end": 1})
         else:
-            infile = PdfFileReader(open(filepath, 'rb'), strict=False)
+            infile = PdfFileReader(open(filepath, "rb"), strict=False)
             if infile.isEncrypted:
                 infile.decrypt(self.password)
-            if pages == 'all':
-                page_numbers.append({'start': 1, 'end': infile.getNumPages()})
+            if pages == "all":
+                page_numbers.append({"start": 1, "end": infile.getNumPages()})
             else:
-                for r in pages.split(','):
-                    if '-' in r:
-                        a, b = r.split('-')
-                        if b == 'end':
+                for r in pages.split(","):
+                    if "-" in r:
+                        a, b = r.split("-")
+                        if b == "end":
                             b = infile.getNumPages()
-                        page_numbers.append({'start': int(a), 'end': int(b)})
+                        page_numbers.append({"start": int(a), "end": int(b)})
                     else:
-                        page_numbers.append({'start': int(r), 'end': int(r)})
+                        page_numbers.append({"start": int(r), "end": int(r)})
         P = []
         for p in page_numbers:
-            P.extend(range(p['start'], p['end'] + 1))
+            P.extend(range(p["start"], p["end"] + 1))
         return sorted(set(P))
 
     def _save_page(self, filepath, page, temp):
@@ -95,16 +102,16 @@ class PDFHandler(object):
             Tmp directory.
 
         """
-        with open(filepath, 'rb') as fileobj:
+        with open(filepath, "rb") as fileobj:
             infile = PdfFileReader(fileobj, strict=False)
             if infile.isEncrypted:
                 infile.decrypt(self.password)
-            fpath = os.path.join(temp, 'page-{0}.pdf'.format(page))
+            fpath = os.path.join(temp, "page-{0}.pdf".format(page))
             froot, fext = os.path.splitext(fpath)
             p = infile.getPage(page - 1)
             outfile = PdfFileWriter()
             outfile.addPage(p)
-            with open(fpath, 'wb') as f:
+            with open(fpath, "wb") as f:
                 outfile.write(f)
             layout, dim = get_page_layout(fpath)
             # fix rotated PDF
@@ -112,23 +119,25 @@ class PDFHandler(object):
             horizontal_text = get_text_objects(layout, ltype="horizontal_text")
             vertical_text = get_text_objects(layout, ltype="vertical_text")
             rotation = get_rotation(chars, horizontal_text, vertical_text)
-            if rotation != '':
-                fpath_new = ''.join([froot.replace('page', 'p'), '_rotated', fext])
+            if rotation != "":
+                fpath_new = "".join([froot.replace("page", "p"), "_rotated", fext])
                 os.rename(fpath, fpath_new)
-                infile = PdfFileReader(open(fpath_new, 'rb'), strict=False)
+                infile = PdfFileReader(open(fpath_new, "rb"), strict=False)
                 if infile.isEncrypted:
                     infile.decrypt(self.password)
                 outfile = PdfFileWriter()
                 p = infile.getPage(0)
-                if rotation == 'anticlockwise':
+                if rotation == "anticlockwise":
                     p.rotateClockwise(90)
-                elif rotation == 'clockwise':
+                elif rotation == "clockwise":
                     p.rotateCounterClockwise(90)
                 outfile.addPage(p)
-                with open(fpath, 'wb') as f:
+                with open(fpath, "wb") as f:
                     outfile.write(f)
 
-    def parse(self, flavor='lattice', suppress_stdout=False, layout_kwargs={}, **kwargs):
+    def parse(
+        self, flavor="lattice", suppress_stdout=False, layout_kwargs={}, **kwargs
+    ):
         """Extracts tables by calling parser.get_tables on all single
         page PDFs.
 
@@ -154,11 +163,13 @@ class PDFHandler(object):
         with TemporaryDirectory() as tempdir:
             for p in self.pages:
                 self._save_page(self.filepath, p, tempdir)
-            pages = [os.path.join(tempdir, 'page-{0}.pdf'.format(p))
-                     for p in self.pages]
-            parser = Lattice(**kwargs) if flavor == 'lattice' else Stream(**kwargs)
+            pages = [
+                os.path.join(tempdir, "page-{0}.pdf".format(p)) for p in self.pages
+            ]
+            parser = Lattice(**kwargs) if flavor == "lattice" else Stream(**kwargs)
             for p in pages:
-                t = parser.extract_tables(p, suppress_stdout=suppress_stdout,
-                                          layout_kwargs=layout_kwargs)
+                t = parser.extract_tables(
+                    p, suppress_stdout=suppress_stdout, layout_kwargs=layout_kwargs
+                )
                 tables.extend(t)
-        return TableList(tables)
+        return TableList(sorted(tables))
