@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 from __future__ import division
 
+import re
 import os
 import sys
 import random
@@ -19,8 +20,14 @@ from pdfminer.pdfpage import PDFTextExtractionNotAllowed
 from pdfminer.pdfinterp import PDFResourceManager
 from pdfminer.pdfinterp import PDFPageInterpreter
 from pdfminer.converter import PDFPageAggregator
-from pdfminer.layout import (LAParams, LTAnno, LTChar, LTTextLineHorizontal,
-                             LTTextLineVertical, LTImage)
+from pdfminer.layout import (
+    LAParams,
+    LTAnno,
+    LTChar,
+    LTTextLineHorizontal,
+    LTTextLineVertical,
+    LTImage,
+)
 
 
 PY3 = sys.version_info[0] >= 3
@@ -35,7 +42,7 @@ else:
 
 
 _VALID_URLS = set(uses_relative + uses_netloc + uses_params)
-_VALID_URLS.discard('')
+_VALID_URLS.discard("")
 
 
 # https://github.com/pandas-dev/pandas/blob/master/pandas/io/common.py
@@ -59,9 +66,11 @@ def is_url(url):
 
 
 def random_string(length):
-    ret = ''
+    ret = ""
     while length:
-        ret += random.choice(string.digits + string.ascii_lowercase + string.ascii_uppercase)
+        ret += random.choice(
+            string.digits + string.ascii_lowercase + string.ascii_uppercase
+        )
         length -= 1
     return ret
 
@@ -79,14 +88,14 @@ def download_url(url):
         Temporary filepath.
 
     """
-    filename = '{}.pdf'.format(random_string(6))
-    with tempfile.NamedTemporaryFile('wb', delete=False) as f:
+    filename = "{}.pdf".format(random_string(6))
+    with tempfile.NamedTemporaryFile("wb", delete=False) as f:
         obj = urlopen(url)
         if PY3:
             content_type = obj.info().get_content_type()
         else:
-            content_type = obj.info().getheader('Content-Type')
-        if content_type != 'application/pdf':
+            content_type = obj.info().getheader("Content-Type")
+        if content_type != "application/pdf":
             raise NotImplementedError("File format not supported")
         f.write(obj.read())
     filepath = os.path.join(os.path.dirname(f.name), filename)
@@ -94,39 +103,39 @@ def download_url(url):
     return filepath
 
 
-stream_kwargs = [
-    'columns',
-    'row_tol',
-    'column_tol'
-]
+stream_kwargs = ["columns", "edge_tol", "row_tol", "column_tol"]
 lattice_kwargs = [
-    'process_background',
-    'line_scale',
-    'copy_text',
-    'shift_text',
-    'line_tol',
-    'joint_tol',
-    'threshold_blocksize',
-    'threshold_constant',
-    'iterations'
+    "process_background",
+    "line_scale",
+    "copy_text",
+    "shift_text",
+    "line_tol",
+    "joint_tol",
+    "threshold_blocksize",
+    "threshold_constant",
+    "iterations",
+    "resolution",
 ]
 
 
-def validate_input(kwargs, flavor='lattice'):
+def validate_input(kwargs, flavor="lattice"):
     def check_intersection(parser_kwargs, input_kwargs):
         isec = set(parser_kwargs).intersection(set(input_kwargs.keys()))
         if isec:
-            raise ValueError("{} cannot be used with flavor='{}'".format(
-                             ",".join(sorted(isec)), flavor))
+            raise ValueError(
+                "{} cannot be used with flavor='{}'".format(
+                    ",".join(sorted(isec)), flavor
+                )
+            )
 
-    if flavor == 'lattice':
+    if flavor == "lattice":
         check_intersection(stream_kwargs, kwargs)
     else:
         check_intersection(lattice_kwargs, kwargs)
 
 
-def remove_extra(kwargs, flavor='lattice'):
-    if flavor == 'lattice':
+def remove_extra(kwargs, flavor="lattice"):
+    if flavor == "lattice":
         for key in kwargs.keys():
             if key in stream_kwargs:
                 kwargs.pop(key)
@@ -256,15 +265,19 @@ def scale_image(tables, v_segments, h_segments, factors):
     v_segments_new = []
     for v in v_segments:
         x1, x2 = scale(v[0], scaling_factor_x), scale(v[2], scaling_factor_x)
-        y1, y2 = scale(abs(translate(-img_y, v[1])), scaling_factor_y), scale(
-            abs(translate(-img_y, v[3])), scaling_factor_y)
+        y1, y2 = (
+            scale(abs(translate(-img_y, v[1])), scaling_factor_y),
+            scale(abs(translate(-img_y, v[3])), scaling_factor_y),
+        )
         v_segments_new.append((x1, y1, x2, y2))
 
     h_segments_new = []
     for h in h_segments:
         x1, x2 = scale(h[0], scaling_factor_x), scale(h[2], scaling_factor_x)
-        y1, y2 = scale(abs(translate(-img_y, h[1])), scaling_factor_y), scale(
-            abs(translate(-img_y, h[3])), scaling_factor_y)
+        y1, y2 = (
+            scale(abs(translate(-img_y, h[1])), scaling_factor_y),
+            scale(abs(translate(-img_y, h[3])), scaling_factor_y),
+        )
         h_segments_new.append((x1, y1, x2, y2))
 
     return tables_new, v_segments_new, h_segments_new
@@ -291,13 +304,13 @@ def get_rotation(chars, horizontal_text, vertical_text):
         rotated 90 degree clockwise.
 
     """
-    rotation = ''
+    rotation = ""
     hlen = len([t for t in horizontal_text if t.get_text().strip()])
     vlen = len([t for t in vertical_text if t.get_text().strip()])
     if hlen < vlen:
         clockwise = sum(t.matrix[1] < 0 and t.matrix[2] > 0 for t in chars)
         anticlockwise = sum(t.matrix[1] > 0 and t.matrix[2] < 0 for t in chars)
-        rotation = 'anticlockwise' if clockwise < anticlockwise else 'clockwise'
+        rotation = "anticlockwise" if clockwise < anticlockwise else "clockwise"
     return rotation
 
 
@@ -325,10 +338,16 @@ def segments_in_bbox(bbox, v_segments, h_segments):
     """
     lb = (bbox[0], bbox[1])
     rt = (bbox[2], bbox[3])
-    v_s = [v for v in v_segments if v[1] > lb[1] - 2 and
-           v[3] < rt[1] + 2 and lb[0] - 2 <= v[0] <= rt[0] + 2]
-    h_s = [h for h in h_segments if h[0] > lb[0] - 2 and
-           h[2] < rt[0] + 2 and lb[1] - 2 <= h[1] <= rt[1] + 2]
+    v_s = [
+        v
+        for v in v_segments
+        if v[1] > lb[1] - 2 and v[3] < rt[1] + 2 and lb[0] - 2 <= v[0] <= rt[0] + 2
+    ]
+    h_s = [
+        h
+        for h in h_segments
+        if h[0] > lb[0] - 2 and h[2] < rt[0] + 2 and lb[1] - 2 <= h[1] <= rt[1] + 2
+    ]
     return v_s, h_s
 
 
@@ -351,9 +370,12 @@ def text_in_bbox(bbox, text):
     """
     lb = (bbox[0], bbox[1])
     rt = (bbox[2], bbox[3])
-    t_bbox = [t for t in text if lb[0] - 2 <= (t.x0 + t.x1) / 2.0
-              <= rt[0] + 2 and lb[1] - 2 <= (t.y0 + t.y1) / 2.0
-              <= rt[1] + 2]
+    t_bbox = [
+        t
+        for t in text
+        if lb[0] - 2 <= (t.x0 + t.x1) / 2.0 <= rt[0] + 2
+        and lb[1] - 2 <= (t.y0 + t.y1) / 2.0 <= rt[1] + 2
+    ]
     return t_bbox
 
 
@@ -385,12 +407,33 @@ def merge_close_lines(ar, line_tol=2):
     return ret
 
 
+def text_strip(text, strip=""):
+    """Strips any characters in `strip` that are present in `text`.
+    Parameters
+    ----------
+    text : str
+        Text to process and strip.
+    strip : str, optional (default: '')
+        Characters that should be stripped from `text`.
+    Returns
+    -------
+    stripped : str
+    """
+    if not strip:
+        return text
+
+    stripped = re.sub(
+        r"[{}]".format("".join(map(re.escape, strip))), "", text, re.UNICODE
+    )
+    return stripped
+
+
 # TODO: combine the following functions into a TextProcessor class which
 # applies corresponding transformations sequentially
 # (inspired from sklearn.pipeline.Pipeline)
 
 
-def flag_font_size(textline, direction, strip_text=''):
+def flag_font_size(textline, direction, strip_text=""):
     """Flags super/subscripts in text by enclosing them with <s></s>.
     May give false positives.
 
@@ -409,10 +452,18 @@ def flag_font_size(textline, direction, strip_text=''):
     fstring : string
 
     """
-    if direction == 'horizontal':
-        d = [(t.get_text(), np.round(t.height, decimals=6)) for t in textline if not isinstance(t, LTAnno)]
-    elif direction == 'vertical':
-        d = [(t.get_text(), np.round(t.width, decimals=6)) for t in textline if not isinstance(t, LTAnno)]
+    if direction == "horizontal":
+        d = [
+            (t.get_text(), np.round(t.height, decimals=6))
+            for t in textline
+            if not isinstance(t, LTAnno)
+        ]
+    elif direction == "vertical":
+        d = [
+            (t.get_text(), np.round(t.width, decimals=6))
+            for t in textline
+            if not isinstance(t, LTAnno)
+        ]
     l = [np.round(size, decimals=6) for text, size in d]
     if len(set(l)) > 1:
         flist = []
@@ -420,21 +471,21 @@ def flag_font_size(textline, direction, strip_text=''):
         for key, chars in groupby(d, itemgetter(1)):
             if key == min_size:
                 fchars = [t[0] for t in chars]
-                if ''.join(fchars).strip():
-                    fchars.insert(0, '<s>')
-                    fchars.append('</s>')
-                    flist.append(''.join(fchars))
+                if "".join(fchars).strip():
+                    fchars.insert(0, "<s>")
+                    fchars.append("</s>")
+                    flist.append("".join(fchars))
             else:
                 fchars = [t[0] for t in chars]
-                if ''.join(fchars).strip():
-                    flist.append(''.join(fchars))
-        fstring = ''.join(flist).strip(strip_text)
+                if "".join(fchars).strip():
+                    flist.append("".join(fchars))
+        fstring = "".join(flist)
     else:
-        fstring = ''.join([t.get_text() for t in textline]).strip(strip_text)
-    return fstring
+        fstring = "".join([t.get_text() for t in textline])
+    return text_strip(fstring, strip_text)
 
 
-def split_textline(table, textline, direction, flag_size=False, strip_text=''):
+def split_textline(table, textline, direction, flag_size=False, strip_text=""):
     """Splits PDFMiner LTTextLine into substrings if it spans across
     multiple rows/columns.
 
@@ -464,38 +515,70 @@ def split_textline(table, textline, direction, flag_size=False, strip_text=''):
     cut_text = []
     bbox = textline.bbox
     try:
-        if direction == 'horizontal' and not textline.is_empty():
-            x_overlap = [i for i, x in enumerate(table.cols) if x[0] <= bbox[2] and bbox[0] <= x[1]]
-            r_idx = [j for j, r in enumerate(table.rows) if r[1] <= (bbox[1] + bbox[3]) / 2 <= r[0]]
+        if direction == "horizontal" and not textline.is_empty():
+            x_overlap = [
+                i
+                for i, x in enumerate(table.cols)
+                if x[0] <= bbox[2] and bbox[0] <= x[1]
+            ]
+            r_idx = [
+                j
+                for j, r in enumerate(table.rows)
+                if r[1] <= (bbox[1] + bbox[3]) / 2 <= r[0]
+            ]
             r = r_idx[0]
-            x_cuts = [(c, table.cells[r][c].x2) for c in x_overlap if table.cells[r][c].right]
+            x_cuts = [
+                (c, table.cells[r][c].x2) for c in x_overlap if table.cells[r][c].right
+            ]
             if not x_cuts:
                 x_cuts = [(x_overlap[0], table.cells[r][-1].x2)]
             for obj in textline._objs:
                 row = table.rows[r]
                 for cut in x_cuts:
                     if isinstance(obj, LTChar):
-                        if (row[1] <= (obj.y0 + obj.y1) / 2 <= row[0] and
-                                (obj.x0 + obj.x1) / 2 <= cut[1]):
+                        if (
+                            row[1] <= (obj.y0 + obj.y1) / 2 <= row[0]
+                            and (obj.x0 + obj.x1) / 2 <= cut[1]
+                        ):
                             cut_text.append((r, cut[0], obj))
                             break
+                        else:
+                            # TODO: add test
+                            if cut == x_cuts[-1]:
+                                cut_text.append((r, cut[0] + 1, obj))
                     elif isinstance(obj, LTAnno):
                         cut_text.append((r, cut[0], obj))
-        elif direction == 'vertical' and not textline.is_empty():
-            y_overlap = [j for j, y in enumerate(table.rows) if y[1] <= bbox[3] and bbox[1] <= y[0]]
-            c_idx = [i for i, c in enumerate(table.cols) if c[0] <= (bbox[0] + bbox[2]) / 2 <= c[1]]
+        elif direction == "vertical" and not textline.is_empty():
+            y_overlap = [
+                j
+                for j, y in enumerate(table.rows)
+                if y[1] <= bbox[3] and bbox[1] <= y[0]
+            ]
+            c_idx = [
+                i
+                for i, c in enumerate(table.cols)
+                if c[0] <= (bbox[0] + bbox[2]) / 2 <= c[1]
+            ]
             c = c_idx[0]
-            y_cuts = [(r, table.cells[r][c].y1) for r in y_overlap if table.cells[r][c].bottom]
+            y_cuts = [
+                (r, table.cells[r][c].y1) for r in y_overlap if table.cells[r][c].bottom
+            ]
             if not y_cuts:
                 y_cuts = [(y_overlap[0], table.cells[-1][c].y1)]
             for obj in textline._objs:
                 col = table.cols[c]
                 for cut in y_cuts:
                     if isinstance(obj, LTChar):
-                        if (col[0] <= (obj.x0 + obj.x1) / 2 <= col[1] and
-                                (obj.y0 + obj.y1) / 2 >= cut[1]):
+                        if (
+                            col[0] <= (obj.x0 + obj.x1) / 2 <= col[1]
+                            and (obj.y0 + obj.y1) / 2 >= cut[1]
+                        ):
                             cut_text.append((cut[0], c, obj))
                             break
+                        else:
+                            # TODO: add test
+                            if cut == y_cuts[-1]:
+                                cut_text.append((cut[0] - 1, c, obj))
                     elif isinstance(obj, LTAnno):
                         cut_text.append((cut[0], c, obj))
     except IndexError:
@@ -503,15 +586,26 @@ def split_textline(table, textline, direction, flag_size=False, strip_text=''):
     grouped_chars = []
     for key, chars in groupby(cut_text, itemgetter(0, 1)):
         if flag_size:
-            grouped_chars.append((key[0], key[1],
-                flag_font_size([t[2] for t in chars], direction, strip_text=strip_text)))
+            grouped_chars.append(
+                (
+                    key[0],
+                    key[1],
+                    flag_font_size(
+                        [t[2] for t in chars], direction, strip_text=strip_text
+                    ),
+                )
+            )
         else:
             gchars = [t[2].get_text() for t in chars]
-            grouped_chars.append((key[0], key[1], ''.join(gchars).strip(strip_text)))
+            grouped_chars.append(
+                (key[0], key[1], text_strip("".join(gchars), strip_text))
+            )
     return grouped_chars
 
 
-def get_table_index(table, t, direction, split_text=False, flag_size=False, strip_text='',):
+def get_table_index(
+    table, t, direction, split_text=False, flag_size=False, strip_text=""
+):
     """Gets indices of the table cell where given text object lies by
     comparing their y and x-coordinates.
 
@@ -550,8 +644,9 @@ def get_table_index(table, t, direction, split_text=False, flag_size=False, stri
     """
     r_idx, c_idx = [-1] * 2
     for r in range(len(table.rows)):
-        if ((t.y0 + t.y1) / 2.0 < table.rows[r][0] and
-                (t.y0 + t.y1) / 2.0 > table.rows[r][1]):
+        if (t.y0 + t.y1) / 2.0 < table.rows[r][0] and (t.y0 + t.y1) / 2.0 > table.rows[
+            r
+        ][1]:
             lt_col_overlap = []
             for c in table.cols:
                 if c[0] <= t.x1 and c[1] >= t.x0:
@@ -561,11 +656,14 @@ def get_table_index(table, t, direction, split_text=False, flag_size=False, stri
                 else:
                     lt_col_overlap.append(-1)
             if len(list(filter(lambda x: x != -1, lt_col_overlap))) == 0:
-                text = t.get_text().strip('\n')
+                text = t.get_text().strip("\n")
                 text_range = (t.x0, t.x1)
                 col_range = (table.cols[0][0], table.cols[-1][1])
-                warnings.warn("{} {} does not lie in column range {}".format(
-                    text, text_range, col_range))
+                warnings.warn(
+                    "{} {} does not lie in column range {}".format(
+                        text, text_range, col_range
+                    )
+                )
             r_idx = r
             c_idx = lt_col_overlap.index(max(lt_col_overlap))
             break
@@ -586,12 +684,26 @@ def get_table_index(table, t, direction, split_text=False, flag_size=False, stri
     error = ((X * (y0_offset + y1_offset)) + (Y * (x0_offset + x1_offset))) / charea
 
     if split_text:
-        return split_textline(table, t, direction, flag_size=flag_size, strip_text=strip_text), error
+        return (
+            split_textline(
+                table, t, direction, flag_size=flag_size, strip_text=strip_text
+            ),
+            error,
+        )
     else:
         if flag_size:
-            return [(r_idx, c_idx, flag_font_size(t._objs, direction, strip_text=strip_text))], error
+            return (
+                [
+                    (
+                        r_idx,
+                        c_idx,
+                        flag_font_size(t._objs, direction, strip_text=strip_text),
+                    )
+                ],
+                error,
+            )
         else:
-            return [(r_idx, c_idx, t.get_text().strip(strip_text))], error
+            return [(r_idx, c_idx, text_strip(t.get_text(), strip_text))], error
 
 
 def compute_accuracy(error_weights):
@@ -642,14 +754,20 @@ def compute_whitespace(d):
     r_nempty_cells, c_nempty_cells = [], []
     for i in d:
         for j in i:
-            if j.strip() == '':
+            if j.strip() == "":
                 whitespace += 1
     whitespace = 100 * (whitespace / float(len(d) * len(d[0])))
     return whitespace
 
 
-def get_page_layout(filename, char_margin=1.0, line_margin=0.5, word_margin=0.1,
-                    detect_vertical=True, all_texts=True):
+def get_page_layout(
+    filename,
+    char_margin=1.0,
+    line_margin=0.5,
+    word_margin=0.1,
+    detect_vertical=True,
+    all_texts=True,
+):
     """Returns a PDFMiner LTPage object and page dimension of a single
     page pdf. See https://euske.github.io/pdfminer/ to get definitions
     of kwargs.
@@ -672,16 +790,18 @@ def get_page_layout(filename, char_margin=1.0, line_margin=0.5, word_margin=0.1,
         Dimension of pdf page in the form (width, height).
 
     """
-    with open(filename, 'rb') as f:
+    with open(filename, "rb") as f:
         parser = PDFParser(f)
         document = PDFDocument(parser)
         if not document.is_extractable:
             raise PDFTextExtractionNotAllowed
-        laparams = LAParams(char_margin=char_margin,
-                            line_margin=line_margin,
-                            word_margin=word_margin,
-                            detect_vertical=detect_vertical,
-                            all_texts=all_texts)
+        laparams = LAParams(
+            char_margin=char_margin,
+            line_margin=line_margin,
+            word_margin=word_margin,
+            detect_vertical=detect_vertical,
+            all_texts=all_texts,
+        )
         rsrcmgr = PDFResourceManager()
         device = PDFPageAggregator(rsrcmgr, laparams=laparams)
         interpreter = PDFPageInterpreter(rsrcmgr, device)
@@ -713,13 +833,13 @@ def get_text_objects(layout, ltype="char", t=None):
         List of PDFMiner text objects.
 
     """
-    if ltype == 'char':
+    if ltype == "char":
         LTObject = LTChar
-    elif ltype == 'image':
+    elif ltype == "image":
         LTObject = LTImage
-    elif ltype == 'horizontal_text':
+    elif ltype == "horizontal_text":
         LTObject = LTTextLineHorizontal
-    elif ltype == 'vertical_text':
+    elif ltype == "vertical_text":
         LTObject = LTTextLineVertical
     if t is None:
         t = []
